@@ -7,7 +7,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Sub::HandlesVia::Mite";
-    our $MITE_VERSION = "0.010008";
+    our $MITE_VERSION = "0.013000";
 
     # Mite keywords
     BEGIN {
@@ -47,10 +47,12 @@
         *false   = \&Sub::HandlesVia::Mite::false;
         *guard   = \&Sub::HandlesVia::Mite::guard;
         *lazy    = \&Sub::HandlesVia::Mite::lazy;
+        *lock    = \&Sub::HandlesVia::Mite::lock;
         *ro      = \&Sub::HandlesVia::Mite::ro;
         *rw      = \&Sub::HandlesVia::Mite::rw;
         *rwp     = \&Sub::HandlesVia::Mite::rwp;
         *true    = \&Sub::HandlesVia::Mite::true;
+        *unlock  = \&Sub::HandlesVia::Mite::unlock;
     }
 
     # Gather metadata for constructor and destructor
@@ -65,8 +67,8 @@
                 map { "$_\::BUILD" } reverse @$linear_isa
             ],
             DEMOLISH => [
-                map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } @$linear_isa
+                map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+                map { "$_\::DEMOLISH" } @$linear_isa
             ],
             HAS_BUILDARGS        => $class->can('BUILDARGS'),
             HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
@@ -126,7 +128,7 @@
 
                 package Sub::HandlesVia::Mite;
                 !ref $args->{"coerce"}
-                  and (!defined $args->{"coerce"}
+                  and ( !defined $args->{"coerce"}
                     or $args->{"coerce"} eq q()
                     or $args->{"coerce"} eq '0'
                     or $args->{"coerce"} eq '1' );
